# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativetestingObjectiveSubCategory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    UNSPECIFIED = "OBJECTIVE_SUB_CATEGORY_UNSPECIFIED"
    THEFT = "OBJECTIVE_SUB_CATEGORY_THEFT"
    POISONING = "OBJECTIVE_SUB_CATEGORY_POISONING"
    VIOLENCE = "OBJECTIVE_SUB_CATEGORY_VIOLENCE"
    STALKING = "OBJECTIVE_SUB_CATEGORY_STALKING"
    TERRORISM = "OBJECTIVE_SUB_CATEGORY_TERRORISM"
    BOMB = "OBJECTIVE_SUB_CATEGORY_BOMB"
    MURDER = "OBJECTIVE_SUB_CATEGORY_MURDER"
    PII_SSN = "OBJECTIVE_SUB_CATEGORY_PII_SSN"
    PII_PHONE_NUMBER = "OBJECTIVE_SUB_CATEGORY_PII_PHONE_NUMBER"
    PII_CREDIT_CARD = "OBJECTIVE_SUB_CATEGORY_PII_CREDIT_CARD"
    PII_EMAIL_ADDRESS = "OBJECTIVE_SUB_CATEGORY_PII_EMAIL_ADDRESS"
    PII_PASSPORT_NUMBER = "OBJECTIVE_SUB_CATEGORY_PII_PASSPORT_NUMBER"
    PIRACY = "OBJECTIVE_SUB_CATEGORY_PIRACY"
    HACKING = "OBJECTIVE_SUB_CATEGORY_HACKING"
    VIRUS = "OBJECTIVE_SUB_CATEGORY_VIRUS"
    MISINFORMATION = "OBJECTIVE_SUB_CATEGORY_MISINFORMATION"
    FINANCIAL_ADVICE = "OBJECTIVE_SUB_CATEGORY_FINANCIAL_ADVICE"
    PII = "OBJECTIVE_SUB_CATEGORY_PII"
    PROMPT_EXTRACTION = "OBJECTIVE_SUB_CATEGORY_PROMPT_EXTRACTION"
    FINANCIAL = "OBJECTIVE_SUB_CATEGORY_FINANCIAL"
    COPYRIGHT_EXTRACTION = "OBJECTIVE_SUB_CATEGORY_COPYRIGHT_EXTRACTION"
    LONG_PROMPTS = "OBJECTIVE_SUB_CATEGORY_LONG_PROMPTS"
    CHILD_PORN = "OBJECTIVE_SUB_CATEGORY_CHILD_PORN"
    DRUGS = "OBJECTIVE_SUB_CATEGORY_DRUGS"
    SUICIDE = "OBJECTIVE_SUB_CATEGORY_SUICIDE"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """GenerativetestingObjectiveSubCategory - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativetestingObjectiveSubCategory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativetestingObjectiveSubCategory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
