# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeRegisterDatasetResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset_id': 'str',
        'registry_validation_job_id': 'RimeUUID'
    }

    attribute_map = {
        'dataset_id': 'datasetId',
        'registry_validation_job_id': 'registryValidationJobId'
    }

    def __init__(self, dataset_id=None, registry_validation_job_id=None):  # noqa: E501
        """RimeRegisterDatasetResponse - a model defined in Swagger"""  # noqa: E501
        self._dataset_id = None
        self._registry_validation_job_id = None
        self.discriminator = None
        if dataset_id is not None:
            self.dataset_id = dataset_id
        if registry_validation_job_id is not None:
            self.registry_validation_job_id = registry_validation_job_id

    @property
    def dataset_id(self):
        """Gets the dataset_id of this RimeRegisterDatasetResponse.  # noqa: E501

        dataset_id is a string as it contains semantic meaning and does not adhere to UUID standard.  # noqa: E501

        :return: The dataset_id of this RimeRegisterDatasetResponse.  # noqa: E501
        :rtype: str
        """
        return self._dataset_id

    @dataset_id.setter
    def dataset_id(self, dataset_id):
        """Sets the dataset_id of this RimeRegisterDatasetResponse.

        dataset_id is a string as it contains semantic meaning and does not adhere to UUID standard.  # noqa: E501

        :param dataset_id: The dataset_id of this RimeRegisterDatasetResponse.  # noqa: E501
        :type: str
        """

        self._dataset_id = dataset_id

    @property
    def registry_validation_job_id(self):
        """Gets the registry_validation_job_id of this RimeRegisterDatasetResponse.  # noqa: E501


        :return: The registry_validation_job_id of this RimeRegisterDatasetResponse.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._registry_validation_job_id

    @registry_validation_job_id.setter
    def registry_validation_job_id(self, registry_validation_job_id):
        """Sets the registry_validation_job_id of this RimeRegisterDatasetResponse.


        :param registry_validation_job_id: The registry_validation_job_id of this RimeRegisterDatasetResponse.  # noqa: E501
        :type: RimeUUID
        """

        self._registry_validation_job_id = registry_validation_job_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeRegisterDatasetResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeRegisterDatasetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
